@@ -9,6 +9,7 @@
 #include <QTranslator>
 
 #include "mainwindow.h"
+#include "common.h"
 #include <chrono>
 
 using namespace std::chrono_literals;
@@ -28,12 +29,12 @@ int main(int argc, char *argv[])
     }
 
     QTranslator qtTran;
-    if (qtTran.load("qt_" + QLocale().name(), QLibraryInfo::location(QLibraryInfo::TranslationsPath))) {
+    if (qtTran.load("qt_" + QLocale().name(), QLibraryInfo::path(QLibraryInfo::TranslationsPath))) {
         QApplication::installTranslator(&qtTran);
     }
 
     QTranslator qtBaseTran;
-    if (qtBaseTran.load("qtbase_" + QLocale().name(), QLibraryInfo::location(QLibraryInfo::TranslationsPath))) {
+    if (qtBaseTran.load("qtbase_" + QLocale().name(), QLibraryInfo::path(QLibraryInfo::TranslationsPath))) {
         QApplication::installTranslator(&qtBaseTran);
     }
 
@@ -82,7 +83,7 @@ int main(int argc, char *argv[])
 
     // Load timeout settings
     QSettings userSettings(QSettings::UserScope, QApplication::organizationName(), QApplication::applicationName());
-    QSettings systemSettings("/etc/exit-options.conf", QSettings::IniFormat);
+    QSettings systemSettings(SYSTEM_CONFIG_PATH, QSettings::IniFormat);
 
     QString timeout;
     if (parser.isSet("timeout")) {
